@@ -13,7 +13,7 @@
 #' testTRUE(FALSE)
 checkTRUE = function(x, na.ok = FALSE) {
   qassert(na.ok, "B1")
-  if (identical(x, TRUE) || (na.ok && length(x) == 1L && is.na(x)))
+  if (isTRUE(x) || (na.ok && length(x) == 1L && is.na(x)))
     return(TRUE)
   return("Must be TRUE")
 }
@@ -26,7 +26,7 @@ check_true = checkTRUE
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkTRUE
-assertTRUE = makeAssertionFunction(checkTRUE)
+assertTRUE = makeAssertionFunction(checkTRUE, use.namespace = FALSE)
 
 #' @export
 #' @rdname checkTRUE
